from distutils.core import setup
#from distutils.extension import Extension
from ramfile_main import __author__, __email__, __url__, __version__, transdir
import sys, os

kw = {}

# List the data files, esp. the .mo files.
kw.setdefault('data_files', []).extend([
    ('', ['ramfile-help', 'ramfile_icon32.png', 'ramfile_icon64.png']),
  ])
locale_dir = '/usr/share/locale'
for lang in os.listdir('locale'):
    mo_path = os.path.join('locale', lang, 'LC_MESSAGES')
    if os.path.isdir(mo_path):
        mo_list = []
        for mo in os.listdir(mo_path):
            mo_list.append(os.path.join(mo_path, mo))
        kw['data_files'].append((
            os.path.join(locale_dir, lang, 'LC_MESSAGES'), mo_list ))

# patch distutils if it can't cope with the "classifiers" or
# "download_url" keywords
if sys.version < '2.2.3':
    from distutils.dist import DistributionMetadata
    DistributionMetadata.classifiers = None
    DistributionMetadata.download_url = None

# Windows .exe stuff
doing_py2exe = False
try:
	import py2exe
except ImportError:
    pass
else:
    doing_py2exe = 'py2exe' in sys.argv     # just a guess, actually
    dist_dir = 'dist/ramfile-exe-'+__version__
    kw['windows'] = ['ramfile_main.py']
    kw.setdefault('options', {})['py2exe'] = {
        'includes': 'pango,atk,gobject',
        #'packages': ['encodings'],     --needed?
        'excludes': 'Tkinter,socket',
        'dist_dir': dist_dir,
      }


long_desc="""Ramfile is a card file program with easy useful searching.

Usage:  ramfile

Ramfile opens properly formatted text files as separate *cards*, and
searches by cards for search words typed in an edit field.  Ramfile can
open ramfile (or QuickFile) card files and mbox (Email) files as cards,
and can also open other text files as a single card.  On my machine,
ramfile can open a 53 MB mbox file in about 7 seconds, and search it in
2 seconds or less.  Ramfile requires GTK, and runs on Linux and
Microsoft Windows if GTK is installed.
"""

setup(
    name='ramfile',
    version=__version__,
    author=__author__,
    author_email=__email__,
    url=__url__,
    description='Card file program with easy useful searching',
    long_description=long_desc,
    license='GPL',
    platforms=['Python >= 2.3'],
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Environment :: X11 Applications :: GTK',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Office/Business',
        'Topic :: Text Editors',
      ],
    scripts=['ramfile'],
    py_modules=['ramfile_main', 'ramfile_ui_gtk'],
    **kw )

# When building a Windows .exe, we need to copy GTK stuff to it, except
# for the unused locales, and copy the relevent .mo files and directory
# structure.
if doing_py2exe:
    import shutil
    def copyovertree(src, dst):
        src = os.path.normpath(src)
        dst = os.path.normpath(dst)
        names = os.listdir(src)
        if not os.path.exists(dst):
            os.mkdir(dst)
        for name in names:
            srcname = os.path.join(src, name)
            dstname = os.path.join(dst, name)
            try:
                if os.path.isdir(srcname):
                    copyovertree(srcname, dstname)
                else:
                    shutil.copy2(srcname, dstname)
            except (IOError, os.error), why:
                print "Can't copy %s to %s: %s" % (`srcname`, `dstname`, str(why))
    def mycopy(dirs):
        for dir in dirs:
            copyovertree(
                os.path.normpath(os.path.join('/GTK', dir)),
                os.path.normpath(os.path.join(dist_dir, dir)) )
    def myrmtree(dir):
        shutil.rmtree(os.path.normpath(os.path.join(dist_dir, dir)))
    def relpath(dir):
        prefix = os.path.commonprefix([dir, os.getcwd()])
        if prefix:
            d = transdir[len(prefix):]
            if os.path.isabs(d):
                d = d[1:]
            if os.path.exists(d):
                dir = d
        return dir
    mycopy(['etc', 'lib', 'share'])
    myrmtree('share/locale')
    myrmtree('share/gtk-2.0')
    if os.path.isdir(transdir):
        print '\nlocale:'
        transdir = relpath(transdir)
        names = os.listdir(transdir)
        for name in names:
            srcname = os.path.normpath(os.path.join(transdir, name, 'LC_MESSAGES'))
            gtkname = os.path.normpath(os.path.join('/GTK/share/locale', name, 'LC_MESSAGES'))
            dstname = os.path.normpath(os.path.join(dist_dir, 'share', 'locale', name, 'LC_MESSAGES'))
            if os.path.isdir(srcname):
                print '  copy "%s"\n    to "%s"' % (srcname, dstname)
                if not os.path.exists(dstname):
                    os.makedirs(dstname)
                copyovertree(srcname, dstname)
                if os.path.isdir(gtkname):
                    print '    and copy "%s"\n    to "%s"' % (gtkname, dstname)
                    copyovertree(gtkname, dstname)
                else:
                    print '    no GTK translation found'
